Core

Struct Core 

pub struct Core<T, S, B, C, const BUF: usize>
where T: Transport, S: Storage, B: BootMetaStore, C: BootCtl,
{ /* private fields */ }
Bootloader entry point. Checks boot state, validates the app, and either boots the application or enters the protocol loop for firmware updates.

Implementations

Source

impl<T, S, B, C, const BUF: usize> Core<T, S, B, C, BUF>
where T: Transport, S: Storage, B: BootMetaStore, C: BootCtl,

pub fn new(platform: Platform<T, S, B, C>) -> Self

Create a new bootloader core from a platform implementation.

pub fn run(self) -> !

Run the bootloader. Checks boot state, validates the app, and either boots the application or enters the protocol loop. Does not return.