macro_rules! app_version {
() => { ... };
}Expand description
Define the .tb_version static using the calling crate’s version.
Place this at module scope in your application binary.
macro_rules! app_version {
() => { ... };
}Define the .tb_version static using the calling crate’s version.
Place this at module scope in your application binary.