macro_rules! boot_version {
() => { ... };
}Expand description
Define the .tb_version static using the calling crate’s version.
Place this at module scope in your bootloader binary.
macro_rules! boot_version {
() => { ... };
}Define the .tb_version static using the calling crate’s version.
Place this at module scope in your bootloader binary.